Module sync

Module sync 

Profile synchronization from remote instances

Structs

ProfileRefreshBatchTask
Batch task for refreshing stale profiles
RemoteProfile
Remote profile response from /me endpoint

Functions

ensure_profile
Ensure a profile exists locally by fetching from remote if needed.
refresh_profile
Refresh an existing profile from remote instance using conditional request.